what.models.detection.yolo API documentation

# what.models.detection.yolo

This module implements YOLO object detection model.

## what.models.detection.yolo.yolov3

## what.models.detection.yolo.yolov3_tiny

## what.models.detection.yolo.yolov4

## what.models.detection.yolo.yolov3_tiny

View Source

     1r'''
     2This module implements YOLO object detection model.
     3
     4<br />
     5
     6## what.models.detection.yolo.yolov3
     7## what.models.detection.yolo.yolov3_tiny
     8## what.models.detection.yolo.yolov4
     9## what.models.detection.yolo.yolov3_tiny
    10
    11'''
    12
    13from what.models.detection.yolo.yolov3 import YOLOV3
    14from what.models.detection.yolo.yolov3_tiny import YOLOV3_TINY
    15
    16from what.models.detection.yolo.yolov4 import YOLOV4
    17from what.models.detection.yolo.yolov4_tiny import YOLOV4_TINY